@@ -20,8 +20,6 @@ import (
 
 	"github.com/stretchr/testify/assert"
 
-	// "k8s.io/apimachinery/pkg/api/resource"
-
 	dw "github.com/devfile/api/v2/pkg/apis/workspaces/v1alpha2"
 	dwo "github.com/devfile/devworkspace-operator/apis/controller/v1alpha1"
 	"github.com/devfile/devworkspace-operator/controllers/controller/devworkspacerouting/solvers"
@@ -1922,7 +1920,8 @@ func TestOverrideGatewayContainerProvisioning(t *testing.T) {
 		},
 	}
 
-	cheSolver.provisionPodAdditions(objs, cheCluster, routing)
+	err := cheSolver.provisionPodAdditions(objs, cheCluster, routing)
+	assert.NoError(t, err)
 
 	assert.Equal(t, overrideCpuRequest.String(), objs.PodAdditions.Containers[0].Resources.Requests.Cpu().String())
 	assert.Equal(t, overrideMemoryRequest.String(), objs.PodAdditions.Containers[0].Resources.Requests.Memory().String())
@@ -1934,7 +1933,6 @@ func TestOverridePartialLimitsGatewayContainerProvisioning(t *testing.T) {
 	overrideMemoryRequest := resource.MustParse("0")
 	overrideCpuRequest := resource.MustParse("0")
 	defaultMemoryLimit := resource.MustParse(constants.DefaultGatewayMemoryLimit)
-	defaultCpuLimit := resource.MustParse(constants.DefaultGatewayCpuLimit)
 
 	cheCluster := &chev2.CheCluster{
 		ObjectMeta: metav1.ObjectMeta{
@@ -1975,11 +1973,12 @@ func TestOverridePartialLimitsGatewayContainerProvisioning(t *testing.T) {
 		},
 	}
 
-	cheSolver.provisionPodAdditions(objs, cheCluster, routing)
+	err := cheSolver.provisionPodAdditions(objs, cheCluster, routing)
+	assert.NoError(t, err)
 
 	assert.Equal(t, overrideCpuRequest.String(), objs.PodAdditions.Containers[0].Resources.Requests.Cpu().String())
 	assert.Equal(t, overrideMemoryRequest.String(), objs.PodAdditions.Containers[0].Resources.Requests.Memory().String())
-	assert.Equal(t, defaultCpuLimit.String(), objs.PodAdditions.Containers[0].Resources.Limits.Cpu().String())
+	assert.Empty(t, objs.PodAdditions.Containers[0].Resources.Limits[corev1.ResourceCPU])
 	assert.Equal(t, defaultMemoryLimit.String(), objs.PodAdditions.Containers[0].Resources.Limits.Memory().String())
 }
 
@@ -2032,7 +2031,8 @@ func TestOverrideGatewayEmptyContainerProvisioning(t *testing.T) {
 		},
 	}
 
-	cheSolver.provisionPodAdditions(objs, cheCluster, routing)
+	err := cheSolver.provisionPodAdditions(objs, cheCluster, routing)
+	assert.NoError(t, err)
 
 	assert.Equal(t, overrideCpuRequest.String(), objs.PodAdditions.Containers[0].Resources.Requests.Cpu().String())
 	assert.Equal(t, overrideMemoryRequest.String(), objs.PodAdditions.Containers[0].Resources.Requests.Memory().String())
@@ -2044,7 +2044,6 @@ func TestDefaultGatewayContainerProvisioning(t *testing.T) {
 	defaultMemoryRequest := resource.MustParse(constants.DefaultGatewayMemoryRequest)
 	defaultCpuRequest := resource.MustParse(constants.DefaultGatewayCpuRequest)
 	defaultMemoryLimit := resource.MustParse(constants.DefaultGatewayMemoryLimit)
-	defaultCpuLimit := resource.MustParse(constants.DefaultGatewayCpuLimit)
 
 	cheCluster := &chev2.CheCluster{
 		ObjectMeta: metav1.ObjectMeta{
@@ -2075,10 +2074,11 @@ func TestDefaultGatewayContainerProvisioning(t *testing.T) {
 		},
 	}
 
-	cheSolver.provisionPodAdditions(objs, cheCluster, routing)
+	err := cheSolver.provisionPodAdditions(objs, cheCluster, routing)
+	assert.NoError(t, err)
 
 	assert.Equal(t, defaultCpuRequest.String(), objs.PodAdditions.Containers[0].Resources.Requests.Cpu().String())
 	assert.Equal(t, defaultMemoryRequest.String(), objs.PodAdditions.Containers[0].Resources.Requests.Memory().String())
-	assert.Equal(t, defaultCpuLimit.String(), objs.PodAdditions.Containers[0].Resources.Limits.Cpu().String())
+	assert.Empty(t, objs.PodAdditions.Containers[0].Resources.Limits[corev1.ResourceCPU])
 	assert.Equal(t, defaultMemoryLimit.String(), objs.PodAdditions.Containers[0].Resources.Limits.Memory().String())
 }
